@@ -64,19 +64,6 @@ Kiten::Kiten( QWidget *parent, const char *name )
   _config = KitenConfigSkeleton::self();
   _config->load();
 
-  /* Set up hot keys */
-  //KDE4 TODO
-/*	Accel = new KGlobalAccel( this );
-  (void) Accel->insert(   "Lookup English/Japanese word"
-                        , i18n("Lookup English/Japanese Word")
-                        , i18n( "Looks up current text on clipboard in the same way as if you used Kiten's regular search." )
-                        , Qt::CTRL | Qt::ALT | Qt::Key_S
-                        , Qt::CTRL | Qt::ALT | Qt::Key_S
-                        , this
-                        , SLOT(searchClipboardContents()) );
-  Accel->readSettings( KSharedConfig::openConfig() );
-  Accel->updateConnections();
-*/
   /* ResultsView is our main widget, displaying the results of a search */
   _mainView = new ResultsView( this, "mainView" );
 
